pub fn wakeup_cause() -> WakeupReasonAvailable on crate feature
unstable only.Expand description
Retrieves the cause(s) of the last wakeup event.
Returns the WakeupReason describing the source(s) that ended
the most recent sleep. The result is empty if the chip was not woken from sleep.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.